%
% ode_airy.m
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
%  Here we solve the problem
% 
% v" - 2 v = - f v - R , on (b,infty), b > 0
%
% where for our program, f = R = -5/(36 t^2),
%                 
% via collocation based on Sinc convolution, 
% and direct solution of the collocated 
% system of algebraic equations corresponding 
% to the integral equation
%
% v(z) = int_z^\infinity 
%
% (1/2) (1 - exp(2z - 2t)) {f(t) v(t) + R(t)} dt
%
% In this case, the exact 1 + v(z) equals 
% 
%  2 pi^{1/2} x^(1/4) e^z Ai(x) , where
%
%  x = (3/2 z)^(2/3)
%
% The "Laplace transform" F(s) = s^2/(1+2s) 
%
% of the convolution kernel is used.  Sinc 
% convolution usually requires computation of the 
% eigenvalues and eigenvectors of the indefinite 
% integration matrix A (see below) to set up the 
% matrix F(A).  However, F(s) is a simple rational 
% in s, and B = F(A) = A*A*(I+2A)^(-1) can thus be 
% easily computed. 
%
clear all
%
% Initializations
%
M=12;
N=10;
m = M+N+1;
h = pi/sqrt(m/2);
%
b = 0.004;    % Solution sought over (b,infinity)

%
% Sinc points and indifinite integration 
%
% matrix over (0,infinity)
%
z = Sincpoints4(M,N,h);
A = Int4_m(M,N,h);
%
for j=1:m
    t = z(j)+b;
    p = (3/2*t)^(1/6); % See (3.9.12)
    f(j) = -5/(36*t^2);
    eta_ex(j) = 2*pi^(1/2)*p*exp(t)*airy(p^4);
end
%
% The matrix B = F(A), and collocation of the IE
%
B = A*inv(eye(m) + 2*A)*A;
D = diag(f);
C = eye(m)-B*D;
R = B*f.';
%
v_apr = C\R + 1;
%
%%%%%%%%%%%%%%  PLOTS  %%%%%%%%%%%%%
%
% Approximate and exact 1 + v
%
MN = M + floor(0.2*N);
for j=1:MN
    Z(j) = z(j);
    Et_apr(j) = v_apr(j);
    Et_ex(j) = eta_ex(j);
end
%
plot(Z,Et_ex,'o',Z,Et_apr)
%
pause
%
plot(Z,Et_apr-Et_ex)
%
pause
%
% Plot of computed (yy) and exact Ai(x)
%
% for  x in (aa, bb).  Here we use 
%
% Sinc interpolation and Eq. 10.4.59 
%
% of [N] to get the approximate 
%
% (yy) values, 
%
aa = (3/2*(z(1)+b))^(2/3);
bb = 2;
step = (bb-aa)/100;
for j=1:101
    x = aa + (j-1)*step;
    xx(j) = x;
    zz = 2/3*x^(1.5) - b;
    uu = phi3(zz);
    ww = basis(uu,M,N,h);
    yy(j) = (ww*v_apr)/2/pi^(1/2)/x^(1/4)/exp(2/3*x^(3/2));
    ai(j) = airy(x);
end
%
figure(1)
plot(xx,yy,'x',xx,ai)
pause
% title('Exact & Approximate Airy')
print -dps2 airy_ex_apr.ps
pause
%
% Plot of error, yy - ai
%
figure(2)
plot(xx,yy-ai)
pause
% title('Error of Aproximating ai')
print -dps2 airy_err.ps
