\begin{verbatim}
%
 -- sinc_1d_quadrature.m
%
% R. Baker Kearfott, 12/18/2002.  Modified by Stenger.
%   Evaluate a definite integral with sinc quadrature

% Computing a function that approximates the derivative
% is very similar to computing an interpolant in 
% sinc-pack. (See sinc_1d_interpolation.m).

N = 50 % This is the number of sinc points to the right 
       % of the center point.  It is the parameter "N" 
       % in Section 1.1 "Sinc Interpolation") of 
       % "Tutorial of Sinc Methods". Advanced users see 
       % "M" below.
       
function_type = 'phi_a_b_log'
       % "function_type" represents the interval over 
       % which the function is defined and the behavior 
       % of the function at the end points.  The 
       % allowable types are:
           %   phi_a_b_log  -- finite interval [a,b]
           %   phi_inf_inf_inv_sinh -- doubly infinite 
           %   interval
       %     [-Inf,Inf]
           %   phi_inf_inf_identity -- doubly infinite 
           %   interval [-Inf,Inf] with an alternate 
           %   sinc point spacing scheme.
           %   phi_a_inf_log_sinh -- semi-infinite 
           %   interval [a,Inf].
           %   phi_a_inf_log -- semi-infinite interval
       %     [a,Inf] with an alternate sinc point 
           %   spacing scheme.
           %    phi_inf_b_log_sinh -- semi-infinite 
                interval [-Inf,b].
           %    phi_inf_b_log -- semi-infinite interval
       %     [-Inf,b] with an alternate sinc pooint 
           %    spacing scheme.
           %    phi_inf_inf_log_sinh_z  infinite 
           %    interval [-Inf,Inf].
       % For further details, see "Explicit 
       % Transformations" in Sec. 4.3.3 of this 
       % tutorial. 
       
a = 0.0  % Left end point of the approximation 
         % interval. It may be set to -Inf if 
         % function_type is set appropriately.

b = 7.0  % Right end point of the approximation 
         % interval.  It may be set to +Inf if 
         % function_type is set appropriately.

function_routine = 'x_to_m2_over_3'
     % This lists a Matlab "m" file where the 
     % function is defined.  An example of the 
     % form is:
     %
     % function [val] = x_to_m2_over_3(misc_data,x)
     %          val = x^(-.6666666666666666667);
     %
     % The above two lines would be stored in the 
     % file "x_to_2_over_3.m" in a directory in the 
     % Matlab search path (such as the directory in 
     % which Matlab is started).


function_data = 'anything'
         % This is any kind of data (matrices, strings, 
         % etc.) that the user wishes to pass to the 
         % Matlab function defined in function_routine. 
         % (See above.)
%====================================================
% Advanced users may wish to change these.

alpha = 0.333;
beta =  1.0;
    % alpha and beta are parameters associated 
    % with the behavior of the function near the 
    % end points of the approximation interval. See 
    % Definition 3.1.5, page 136, Stenger, "Numerical 
    % Methods Based on Sinc and Analytic Functions," 
    % Springer Verlag, 1993.

M = floor((beta * N) / alpha);

       
d = pi/2;This is the theoretical value, often pi/2, 
       % as introduced in (1.7.9), p. 67 of Stenger, 
       % "Numerical Methods Based on Sinc and 
       % Analytic Functions," Springer Verlag, 1993.


h = sqrt( pi * d / (\beta * N )); % h affects spacing of 
       % the sinc points.

% end of advanced user section.
%===================================================

% Return the sinc points in pos_vec and return the sinc 
% interpolation coefficients for the original function
% in coeff_vec.

[coeff_vec, pos_vec]
    = get_1d_interp_coefficients(function_routine,...
                         function_data, ...
                         function_type, a, b, ...
                         M, N, h);


% Sinc quadrature.

[squad] = mtlb_sp_quad_2(coeff_vec, ...
                         function_type, a, b, ...
                         M, N, h);

% Compare with the exact result for illustration 
% purposes --
exact_integral = (3)*7^(1/3);
format long
'sinc quadrature comparisons:'
N
squad
exact_integral
relative_error = (squad-exact_integral)/exact_integral

% Output: 
% 
% ns =
% 
% sinc quadrature comparisons:
% 
% 
% N = 50
%  
% squad =  5.73644680110472
% 
% exact_integral =  5.73879354831717
%  
% relative_error =  -4.089269273565209e-04
% 
\end{verbatim}


