%  R. Baker Kearfott, 12/18/2002 -- sinc_1d_convolution.m
%   Evaluate the indefinite convolution from x to b of
%   f and g at sinc points, that is, evaluate
%   \int_{t=x}^b f(t-x) g(t) dt.
%   To compute this, the user inputs G(s) = F(1/s) and g(t), where
%   F(s) is the Laplace transform of f(t).  For example, below,
%   f(t) = 1, so G(s) = s.


N = 5  % This is the number of sinc points to the right of the
       % center point.  It is the parameter "N" in Section 1.1
       % "Sinc Interpolation") of "Tutorial of Sinc Methods".
       % Advanced users see "M" below.

G_type = 'phi_a_b_log'
       % "G_type" represents the interval over which
       % the function is defined and the behavior of the
       % function at the end points.  The allowable types
       % are:
	   %     phi_a_b_log  -- finite interval [a,b]
	   %     phi_inf_inf_inv_sinh -- doubly infinite interval
       %        [-Inf,Inf]
	   %     phi_inf_inf_identity -- doubly infinite interval
       %        [-Inf,Inf] with an alternate sinc point spacing
       %        scheme.
	   %     phi_a_inf_log_sinh -- semi-infinite interval
       %        [a,Inf].
	   %     phi_a_inf_log -- semi-infinite interval
       %        [a,Inf] with an alternate sinc point spacing
       %        scheme.
	   %     phi_inf_b_log_sinh -- semi-infinite interval
       %        [-Inf,b].
	   %     phi_inf_b_log -- semi-infinite interval
       %        [-Inf,b] with an alternate sinc pooint spacing
       %        scheme.
	   %     phi_inf_inf_log_sinh_z  infinite interval [-Inf,Inf].
       % For further details, see "Explicit Transformations" in
       % appendix "A" of "Tutorial of Sinc Methods."

G_routine = 'frac_1_3'
% G_routine = 'identity_1d'
         % This lists a Matlab "m" file where the function G is
         % defined.  An example of the form is:
         %
         %       function [val] = x_to_minus_1_over_3(misc_data,s)
         %          val = s;
         %
         % The above two lines would be stored in the file
         % "x_to_2_over_3.m" in a directory in the Matlab
         % search path (such as the directory in which Matlab
         % is started).

G_data = 'anything'
       % This is any kind of data (matrices, strings, etc.)
       % that the user wishes to pass to the Matlab function
       % defined in function_routine. (See above.)

g_routine = 'x_to_minus_1_over_3'
         % This lists a Matlab "m" file where the function g is
         % defined.  An example of the form is:
         %
         %       function [val] = x_to_minus_1_over_3(misc_data,x)
         %          val = x^(-.33333333333333333333);
         %
         % The above two lines would be stored in the file
         % "x_to_2_over_3.m" in a directory in the Matlab
         % search path (such as the directory in which Matlab
         % is started).

g_data = 'anything'


a = 0.0  % Left end point of the approximation interval. It may
         % be set to -Inf if function_type is set appropriately.

b = 1.0  % Right end point of the approximation interval.  It may
         % be set to +Inf if function_type is set appropriately.

function_routine = 'x_to_minus_1_over_3'
         % This lists a Matlab "m" file where the function is
         % defined.  An example of the form is:
         %
         %       function [val] = x_to_minus_1_over_3(misc_data,x)
         %          val = x^(-.33333333333333333333);
         %
         % The above two lines would be stored in the file
         % "x_to_2_over_3.m" in a directory in the Matlab
         % search path (such as the directory in which Matlab
         % is started).


%====================================================================
% Advanced users may wish to change these.

M = 0; % M must be set to 0 for the particular routines used here.

alpha = .6666666666666666667;
beta =  1.0;
       % alpha and beta are parameters associated with the
       % behavior of the function near the end points of
       % the approximation interval. See Definition 3.1.5,
       % page 136, Stenger, "Numerical Methods Based
       % on Sinc and Analytic Functions," Springer Verlag, 1993.

d = pi/2;% This is the theoretical value, normally pi/2, as introduced
         % in (1.7.9), p. 67 of Stenger, "Numerical Methods Based
         % on Sinc and Analytic Functions," Springer Verlag, 1993.


% end of advanced user section.
%====================================================================

% Compute the convolution, returning the values in "solution" and
% the evaluation points in "zi" --

[convolution_values,zi] = sp_1d_convolution...
    (G_routine, G_data, g_routine, g_data, ...
     G_type, a, b, M, N, d, alpha, beta);

% Compute the exact convolution in this case for illustration --
exact_value = (3./2.)*(1.-zi.^(2./3.));

% Plot the approximate and exact convolutions --

plot(zi,exact_value,'o', zi,convolution_values)
